package com.bigdata.dis.sdk.demo;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.huaweicloud.dis.DIS;
import com.huaweicloud.dis.DISClientBuilder;
import com.huaweicloud.dis.exception.DISClientException;
import com.huaweicloud.dis.iface.data.request.GetPartitionCursorRequest;
import com.huaweicloud.dis.iface.data.request.GetRecordsRequest;
import com.huaweicloud.dis.iface.data.response.GetPartitionCursorResult;
import com.huaweicloud.dis.iface.data.response.GetRecordsResult;
import com.huaweicloud.dis.iface.data.response.Record;
import com.huaweicloud.dis.util.PartitionCursorTypeEnum;

public class ConsumerDemo
{
    private static final Logger log = LoggerFactory.getLogger(ConsumerDemo.class);

    public static void main(String args[])
    {
        runConsumerDemo();
    }

    private static void runConsumerDemo()
    {
        // 创建DIS客户端实例
        DIS dic = DISClientBuilder.standard()
                .withEndpoint("https://dis.cn-north-1.myhwclouds.com:20004")
                .withAk("xxxx")
                .withSk("xxxx")
                .withProjectId("xxxxxxx")
                .withRegion("cn-north-1")
                .build();

        // 配置流名称
        String streamName = "streamName";

        // 配置数据下载分区ID
        String partitionId = "0";

        // 配置下载数据序列号
        String startingSequenceNumber = "0";

        // 配置下载数据方式
        String cursorType = PartitionCursorTypeEnum.AT_SEQUENCE_NUMBER.name();

        try
        {
            // 获取数据游标
            GetPartitionCursorRequest request = new GetPartitionCursorRequest();
            request.setStreamName(streamName);
            request.setPartitionId(partitionId);
            request.setStartingSequenceNumber(startingSequenceNumber);
            request.setCursorType(cursorType);
            GetPartitionCursorResult response = dic.getPartitionCursor(request);
            String cursor = response.getPartitionCursor();

            log.info("Get stream {}[partitionId={}] cursor success : {}", streamName, partitionId, cursor);

            GetRecordsRequest recordsRequest = new GetRecordsRequest();
            GetRecordsResult recordResponse = null;
            while (true)
            {
                recordsRequest.setPartitionCursor(cursor);
                recordsRequest.setLimit(2);
                recordResponse = dic.getRecords(recordsRequest);
                // 下一批数据游标
                cursor = recordResponse.getNextPartitionCursor();

                for (Record record : recordResponse.getRecords())
                {
                    log.info("Get Record [{}], partitionKey [{}], sequenceNumber [{}].",
                            new String(record.getData().array()),
                            record.getPartitionKey(),
                            record.getSequenceNumber());
                }
                Thread.sleep(1000);
            }
        }
        catch (DISClientException e)
        {
            log.error("Failed to get a normal response, please check params and retry. Error message [{}]",
                    e.getMessage(),
                    e);
        }
        catch (Exception e)
        {
            log.error(e.getMessage(), e);
        }
    }
}
