package com.bigdata.dis.sdk.demo;

import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ThreadLocalRandom;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.huaweicloud.dis.DIS;
import com.huaweicloud.dis.DISClientBuilder;
import com.huaweicloud.dis.exception.DISClientException;
import com.huaweicloud.dis.iface.data.request.PutRecordsRequest;
import com.huaweicloud.dis.iface.data.request.PutRecordsRequestEntry;
import com.huaweicloud.dis.iface.data.response.PutRecordsResult;
import com.huaweicloud.dis.iface.data.response.PutRecordsResultEntry;

public class ProducerDemo
{
    private static final Logger log = LoggerFactory.getLogger(ProducerDemo.class);

    public static void main(String args[])
    {
        runProduceDemo();
    }

    private static void runProduceDemo()
    {
        // 创建DIS客户端实例
        DIS dic = DISClientBuilder.standard()
                .withEndpoint("https://10.63.195.73:8443")
                .withAk("MQW3GD3ZGQ2HVYMBMFC8")
                .withSk("RDaSo9Fx7sX9thhI93mJ6Ges8IEKuNRhpqnAd6x6")
                .withProjectId("549e1a771213446797d527119f2d9bc4")
                .withRegion("southchina")
                .build();

        // 配置流名称
        String streamName = "dis-OHG5";

        // 配置上传的数据
        String message = "{\n" +
                "    \"orgId\":\"4\",\n" +
                "    \"equipmentId\":\"1\",\n" +
                "    \"date\":\"2017/10/1 06:00:00\",\n" +
                "    \"cpu\":15,\n" +
                "    \"disk\":50,\n" +
                "    \"data\":[\n" +
                "        {\n" +
                "            \"metric\":\"memory\",\n" +
                "            \"value\":15\n" +
                "        },\n" +
                "        {\n" +
                "            \"metric\":\"cache\",\n" +
                "            \"value\":5\n" +
                "        }\n" +
                "    ]\n" +
                "}";

        PutRecordsRequest putRecordsRequest = new PutRecordsRequest();
        putRecordsRequest.setStreamName(streamName);
        List<PutRecordsRequestEntry> putRecordsRequestEntryList = new ArrayList<PutRecordsRequestEntry>();
        ByteBuffer buffer = ByteBuffer.wrap(message.getBytes());
        for (int i = 0; i < 1; i++)
        {
            PutRecordsRequestEntry putRecordsRequestEntry = new PutRecordsRequestEntry();
            putRecordsRequestEntry.setData(buffer);
            putRecordsRequestEntry.setPartitionKey(String.valueOf(ThreadLocalRandom.current().nextInt(1000000)));
            putRecordsRequestEntryList.add(putRecordsRequestEntry);
        }
        putRecordsRequest.setRecords(putRecordsRequestEntryList);

        log.info("========== BEGIN PUT ============");

        PutRecordsResult putRecordsResult = null;
        try
        {
            putRecordsResult = dic.putRecords(putRecordsRequest);
        }
        catch (DISClientException e)
        {
            log.error("Failed to get a normal response, please check params and retry. Error message [{}]",
                    e.getMessage(),
                    e);
        }
        catch (Exception e)
        {
            log.error(e.getMessage(), e);
        }

        if (putRecordsResult != null)
        {
            log.info("Put {} records[{} successful / {} failed].",
                    putRecordsResult.getRecords().size(),
                    putRecordsResult.getRecords().size() - putRecordsResult.getFailedRecordCount().get(),
                    putRecordsResult.getFailedRecordCount());

            for (int j = 0; j < putRecordsResult.getRecords().size(); j++)
            {
                PutRecordsResultEntry putRecordsRequestEntry = putRecordsResult.getRecords().get(j);
                if (putRecordsRequestEntry.getErrorCode() != null)
                {
                    // 上传失败
                    log.error("[{}] put failed, errorCode [{}], errorMessage [{}]",
                            new String(putRecordsRequestEntryList.get(j).getData().array()),
                            putRecordsRequestEntry.getErrorCode(),
                            putRecordsRequestEntry.getErrorMessage());
                }
                else
                {
                    // 上传成功
                    log.info("[{}] put success, partitionId [{}], partitionKey [{}], sequenceNumber [{}]",
                            new String(putRecordsRequestEntryList.get(j).getData().array()),
                            putRecordsRequestEntry.getPartitionId(),
                            putRecordsRequestEntryList.get(j).getPartitionKey(),
                            putRecordsRequestEntry.getSequenceNumber());
                }
            }
        }
        log.info("========== END PUT ============");
    }

}
